@@ -295,4 +295,17 @@ from PPshare.news.news_baidu import (
     news_economic_baidu,
     news_trade_notify_suspend_baidu,
     news_report_time_baidu,
+)
+"""
+新闻联播
+"""
+from PPshare.xwlb import news_cctv
+
+"""
+新经济
+"""
+from PPshare.xjj import (
+    death_company,
+    nicorn_company,
+    maxima_company
 )
\ No newline at end of file
